# DoiT DocOps Python Package

_Python library and CLI tools for doing DocOps at DoiT_

**Table of contents:**

- [Install](#install)
- [Documentation](#documentation)
  - [Users](#users)
  - [Developers](#developers)

## Install

You can install the [doitintl-docops][pypi-project] package using [Pip][pip]:

```console
$ pip install doitintl-docops
Collecting doit-docops
  Downloading doitintl_docops-2.0.0-py3-none-any.whl (175 kB)
[...]
Successfully installed doitintl_docops-2.0.0
```

The [project releases][releases] page has a complete list of all releases and
the corresponding release notes. If you prefer to install the package manually,
each release page has links to multiple release assets.

## Documentation

> 📝&nbsp;&nbsp;**Note**
>
> Documentation is sparse at the moment because this project is still in the
> early stages of development.

### Users

- [Glossary utilities][user-gloss]
- [GitBook client][user-gitbook]

### Developers

- [Python development][dev-python]

<!-- Link references go below this line, sorted ascending --->

[dev-python]:
 https://github.com/doitintl/docops-python/blob/main/docs/dev/python.md
[pip]: https://pip.pypa.io/en/stable/
[pypi-project]: https://pypi.org/project/doitintl-docops
[releases]: https://github.com/doitintl/docops-python/releases
[user-gitbook]:
 https://github.com/doitintl/docops-python/blob/main/docs/user/gitbook.md
[user-gloss]:
 https://github.com/doitintl/docops-python/blob/main/docs/user/gloss.md
